---
meta:
  id: uvsqsat
  endian: be
doc: |
  : UVSQsat telemtry description file 
  : Version 0.0.5 
  :
  : 
  :
  :field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
  :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
  :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
  :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
  :field ctl: ax25_frame.ax25_header.ctl
  :field pid: ax25_frame.payload.pid
  

seq:
  - id: ax25_frame
    type: ax25_frame
    doc-ref: 'https://www.tapr.org/pub_ax25.html'

types:
  ax25_frame:
    seq:
      - id: ax25_header
        type: ax25_header
      - id: payload
        type:
          switch-on: ax25_header.ctl & 0x13
          cases:
            0x03: ui_frame
            0x13: ui_frame
            0x00: i_frame
            0x02: i_frame
            0x10: i_frame
            0x12: i_frame
            _: i_frame
            # 0x11: s_frame

  ax25_header:
    seq:
      - id: dest_callsign_raw
        type: callsign_raw
      - id: dest_ssid_raw
        type: ssid_mask
      - id: src_callsign_raw
        type: callsign_raw
      - id: src_ssid_raw
        type: ssid_mask
      - id: ctl
        type: u1

  callsign_raw:
    seq:
      - id: callsign_ror
        process: ror(1)
        size: 6
        type: callsign

  callsign:
    seq:
      - id: callsign
        type: str
        encoding: ASCII
        size: 6

  ssid_mask:
    seq:
      - id: ssid_mask
        type: u1
    instances:
      ssid:
        value: (ssid_mask & 0x0f) >> 1

  i_frame:
    seq:
      - id: pid
        type: u1
      - id: ax25_info
        size-eos: true

  ui_frame:
    seq:
      - id: pid
        type: u1
      - id: packet_primary_header
        type: packet_primary_header
      - id: packet_secondary_header
        type: packet_secondary_header
      - id: tlm
        type:
          switch-on: packet_secondary_header.sid
          cases:
            0x0E: amsat_ascii
            0x0F: beacon
            0x10: ants_hk
            0x11: obc_status
            0x12: obc_hk
            0x13: mainboard_all_science
            0x14: mainboard_hk
            0x15: ieps_hk_status
            0x16: trxvurx_hk
            0x17: imtq_hk 
            0x18: trxvutx_hk
            _: msg_or_unknow
            
      - id: ax25_info
        size-eos: true
# for command status and other message not recognised  
  msg_or_unknow:
    seq:
      - id: data
        size-eos: true
        
# CCDS - primary packet header 
  packet_primary_header:
    seq:
      - id: packet_version_number
        type: b3
      - id: packet_id_packet_type
        type: b1
      - id: packet_id_secondary_header_flag
        type: b1
      - id: packet_id_application_process_id
        type: b11 
      - id: packet_sequence_control_secquence_flag
        type: b2
      - id: packet_sequence_control_count_or_name
        type: b14
      - id: packet_data_length
        type: u2
        
# CCDS - secondary  packet header 
  packet_secondary_header:
    seq:
      - id:  tm_packet_pus_version_number
        type: b4
      - id: spacecraft_time_reference_status
        type: b4
      - id: service_type_id
        type: u1
      - id: message_subtype_id
        type: u1
      - id: message_type_counter
        type: u2
      - id: destination_id
        type: u2
      - id: time
        type: u4
      - id: dummy1 # to verify 
        type: u2
      - id: dummy2 # to verify 
        type: u1
      - id: sid # used to identify the frame type
        type: u1
################################################################################
#
#   Ants Hk
#
################################################################################
  ants_hk:
    seq:
      - id: side_a_ants_temperature
        type: u2
      - id: side_a_ants_deployment_status
        type: u2
      - id: side_a_ants_uptime
        type: u4
      - id: side_a_deployment_count_antenna_1
        type: u1
      - id: side_a_deployment_count_antenna_2
        type: u1
      - id: side_a_deployment_count_antenna_3
        type: u1
      - id: side_a_deployment_count_antenna_4
        type: u1
      - id: side_a_deployment_time_antenna_1
        type: u2
      - id: side_a_deployment_time_antenna_2
        type: u2
      - id: side_a_deployment_time_antenna_3
        type: u2
      - id: side_a_deployment_time_antenna_4
        type: u2
      - id: side_b_ants_temperature
        type: u2
      - id: side_b_ants_deployment_status
        type: u2
      - id: side_b_ants_uptime
        type: u2
      - id: side_b_deployment_count_antenna_1
        type: u1
      - id: side_b_deployment_count_antenna_2
        type: u1
      - id: side_b_deployment_count_antenna_3
        type: u1
      - id: side_b_deployment_count_antenna_4
        type: u1
      - id: side_b_deployment_time_antenna_1
        type: u2
      - id: side_b_deployment_time_antenna_2
        type: u2
      - id: side_b_deployment_time_antenna_3
        type: u2
      - id: side_b_deployment_time_antenna_4
        type: u2
    instances:
     side_a_ants_temperature_raw:
      value:  side_a_ants_temperature
     side_a_ants_deployment_status_raw:
      value: side_a_ants_deployment_status
     side_a_ants_uptime_raw:
      value: side_a_ants_uptime
     side_a_deployment_count_antenna_1_raw:
      value: side_a_deployment_count_antenna_1
     side_a_deployment_count_antenna_2_raw:
      value: side_a_deployment_count_antenna_2
     side_a_deployment_count_antenna_3_raw:
      value: side_a_deployment_count_antenna_3
     side_a_deployment_count_antenna_4_raw:
      value: side_a_deployment_count_antenna_4
     side_a_deployment_time_antenna_1_raw:
      value: side_a_deployment_time_antenna_1
     side_a_deployment_time_antenna_2_raw:
      value: side_a_deployment_time_antenna_2
     side_a_deployment_time_antenna_3_raw:
      value: side_a_deployment_time_antenna_3
     side_a_deployment_time_antenna_4_raw:
      value: side_a_deployment_time_antenna_4
     side_b_ants_temperature_raw:
      value: side_b_ants_temperature
     side_b_ants_deployment_status_raw:
      value: side_b_ants_deployment_status
     side_b_ants_uptime_raw:
      value: side_b_ants_uptime
     side_b_deployment_count_antenna_1_raw:
      value: side_b_deployment_count_antenna_1
     side_b_deployment_count_antenna_2_raw:
      value: side_b_deployment_count_antenna_2
     side_b_deployment_count_antenna_3_raw:
      value: side_b_deployment_count_antenna_3
     side_b_deployment_count_antenna_4_raw:
      value: side_b_deployment_count_antenna_4
     side_b_deployment_time_antenna_1_raw:
      value: side_b_deployment_time_antenna_1
     side_b_deployment_time_antenna_2_raw:
      value: side_b_deployment_time_antenna_2
     side_b_deployment_time_antenna_3_raw:
      value: side_b_deployment_time_antenna_3
     side_b_deployment_time_antenna_4_raw:
      value: side_b_deployment_time_antenna_4 
################################################################################
#
#   Mainboard All Science
#
################################################################################      
  mainboard_all_science:
    seq:
      - id: mainboard_science_time
        type: u4
      - id: teachwear_on
        type: u1
      - id: frequence_of_acquisitions
        type: u2
      - id: gainain
        type: u4
      - id: number_of_acquisition_per_science_for_e_r_s
        type: u2
      - id: number_of_acquisition_per_science_for_u_v_s
        type: u2
      - id: fee_plus_x_ers1_signal
        type: u4
      - id: fee_plus_x_ers1_temperature
        type: u4
      - id: fee_plus_x_ers2_signal
        type: u4
      - id: fee_plus_x_ers2_temperature
        type: u4
      - id: fee_plus_x_ers3_signal
        type: u4
      - id: fee_plus_x_ers3_temperature
        type: u4
      - id: fee_plus_x_uvs_signal
        type: u4
      - id: fee_minus_x_ers1_signal
        type: u4
      - id: fee_minus_x_ers1_temperature
        type: u4
      - id: fee_minus_x_ers2_signal
        type: u4
      - id: fee_minus_x_ers2_temperature
        type: u4
      - id: fee_minus_x_ers3_signal
        type: u4
      - id: fee_minus_x_ers3_temperature
        type: u4
      - id: fee_minus_x_uvs_signal
        type: u4
      - id: fee_plus_y_ers1_signal
        type: u4
      - id: fee_plus_y_ers1_temperature
        type: u4
      - id: fee_plus_y_ers2_signal
        type: u4
      - id: fee_plus_y_ers2_temperature
        type: u4
      - id: fee_plus_y_ers3_signal
        type: u4
      - id: fee_plus_y_ers3_temperature
        type: u4
      - id: fee_plus_y_uvs_signal
        type: u4
      - id: fee_minus_y_ers1_signal
        type: u4
      - id: fee_minus_y_ers1_temperature
        type: u4
      - id: fee_minus_y_ers2_signal
        type: u4
      - id: fee_minus_y_ers2_temperature
        type: u4
      - id: fee_minus_y_ers3_signal
        type: u4
      - id: fee_minus_y_ers3_temperature
        type: u4
      - id: fee_minus_y_uvs_signal
        type: u4
      - id: teachwear_acc_x
        type: u2
      - id: teachwear_acc_y
        type: u2
      - id: teachwear_acc_z
        type: u2
      - id: teachwear_deg_c
        type: u2
      - id: teachwear_gyro_x
        type: u2
      - id: teachwear_gyro_y
        type: u2
      - id: teachwear_gyro_z
        type: u2
      - id: teachwear_magn_x
        type: u2
      - id: teachwear_magn_y
        type: u2
      - id: teachwear_magn_z
        type: u2
      - id: teachwear_state
        type: u1
      - id: teachwear_reset_reason
        type: u1
      - id: teachwear_c_r_c
        type: u2     
    instances:
     mainboard_science_time_raw:
      value: mainboard_science_time
     teachwear_on_raw:
      value: teachwear_on
     frequence_of_acquisitions_raw:
      value: frequence_of_acquisitions
     gainain_raw:
      value: gainain
     number_of_acquisition_per_science_for_e_r_s_raw:
      value: number_of_acquisition_per_science_for_e_r_s
     number_of_acquisition_per_science_for_u_v_s_raw:
      value: number_of_acquisition_per_science_for_u_v_s
     fee_plus_x_ers1_signal_raw:
      value: fee_plus_x_ers1_signal
     fee_plus_x_ers1_temperature_raw:
      value: fee_plus_x_ers1_temperature
     fee_plus_x_ers2_signal_raw:
      value: fee_plus_x_ers2_signal
     fee_plus_x_ers2_temperature_raw:
      value: fee_plus_x_ers2_temperature
     fee_plus_x_ers3_signal_raw:
      value: fee_plus_x_ers3_signal
     fee_plus_x_ers3_temperature_raw:
      value: fee_plus_x_ers3_temperature
     fee_plus_x_uvs_signal_raw:
      value: fee_plus_x_uvs_signal
     fee_minus_x_ers1_signal_raw:
      value: fee_minus_x_ers1_signal
     fee_minus_x_ers1_temperature_raw:
      value: fee_minus_x_ers1_temperature
     fee_minus_x_ers2_signal_raw:
      value: fee_minus_x_ers2_signal
     fee_minus_x_ers2_temperature_raw:
      value: fee_minus_x_ers2_temperature
     fee_minus_x_ers3_signal_raw:
      value: fee_minus_x_ers3_signal
     fee_minus_x_ers3_temperature_raw:
      value: fee_minus_x_ers3_temperature
     fee_minus_x_uvs_signal_raw:
      value: fee_minus_x_uvs_signal
     fee_plus_y_ers1_signal_raw:
      value: fee_plus_y_ers1_signal
     fee_plus_y_ers1_temperature_raw:
      value: fee_plus_y_ers1_temperature
     fee_plus_y_ers2_signal_raw:
      value: fee_plus_y_ers2_signal
     fee_plus_y_ers2_temperature_raw:
      value: fee_plus_y_ers2_temperature
     fee_plus_y_ers3_signal_raw:
      value: fee_plus_y_ers3_signal
     fee_plus_y_ers3_temperature_raw:
      value: fee_plus_y_ers3_temperature
     fee_plus_y_uvs_signal_raw:
      value: fee_plus_y_uvs_signal
     fee_minus_y_ers1_signal_raw:
      value: fee_minus_y_ers1_signal
     fee_minus_y_ers1_temperature_raw:
      value: fee_minus_y_ers1_temperature
     fee_minus_y_ers2_signal_raw:
      value: fee_minus_y_ers2_signal
     fee_minus_y_ers2_temperature_raw:
      value: fee_minus_y_ers2_temperature
     fee_minus_y_ers3_signal_raw:
      value: fee_minus_y_ers3_signal
     fee_minus_y_ers3_temperature_raw:
      value: fee_minus_y_ers3_temperature
     fee_minus_y_uvs_signal_raw:
      value: fee_minus_y_uvs_signal
     teachwear_acc_x_raw:
      value: teachwear_acc_x
     teachwear_acc_y_raw:
      value:  teachwear_acc_y
     teachwear_acc_z_raw:
      value: teachwear_acc_z
     teachwear_deg_c_raw:
      value: teachwear_deg_c
     teachwear_gyro_x_raw:
      value: teachwear_gyro_x
     teachwear_gyro_y_raw:
      value: teachwear_gyro_y
     teachwear_gyro_z_raw:
      value: teachwear_gyro_z
     teachwear_magn_x_raw:
      value: teachwear_magn_x
     teachwear_magn_y_raw:
      value: teachwear_magn_y
     teachwear_magn_z_raw:
      value: teachwear_magn_z
     teachwear_state_raw:
      value: teachwear_state
     teachwear_reset_reason_raw:
      value: teachwear_reset_reason
     teachwear_c_r_c_raw:
      value: teachwear_c_r_c           
################################################################################
#
#   AMSAT ASCII
#
################################################################################ 
  amsat_ascii:
    seq:
      - id: message
        type: str
        size-eos: true
        encoding: UTF-8
    instances:
     message_str:
      value: message
        
  mainboard_hk:
    seq:
      - id: mainboard_h_k_time
        type: u4
      - id: h_k_plus_5_v
        type: u2
      - id: h_k_minus_5_v
        type: u2
      - id: h_k_minus_polar
        type: u2
      - id: h_k_temp_a_d_c
        type: u2
      - id: h_k_fee_plus_x_vref
        type: u2
      - id: h_k_fee_minus_x_vref
        type: u2
      - id: h_k_fee_plus_y_vref
        type: u2
      - id: h_k_fee_minus_y_vref
        type: u2
    instances:
     mainboard_h_k_time_raw:
      value: mainboard_h_k_time
     h_k_plus_5_v_raw:
      value: h_k_plus_5_v
     h_k_minus_5_v_raw:
      value: h_k_minus_5_v
     h_k_minus_polar_raw:
      value: h_k_minus_polar
     h_k_temp_a_d_c_raw:
      value: h_k_temp_a_d_c
     h_k_fee_plus_x_vref_raw:
      value: h_k_fee_plus_x_vref
     h_k_fee_minus_x_vref_raw:
      value: h_k_fee_minus_x_vref
     h_k_fee_plus_y_vref_raw:
      value: h_k_fee_plus_y_vref
     h_k_fee_minus_y_vref_raw:
      value: h_k_fee_minus_y_vref
################################################################################
#
#   trxvurx HK
#
################################################################################       
  trxvurx_hk:
    seq:
      - id: instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: supply_voltage
        type: b12
      - id: total_supply_current
        type: b12
      - id: transmitter_current
        type: b12
      - id: receiver_current
        type: b12
      - id: power_amplifier_current
        type: b12
      - id: power_amplifier_temperature
        type: b12
      - id: local_oscillator_temperature
        type: b12
      - id: zero__padding
        type: b4
      - id: trxvu_rx_uptime
        type: u4
# référence table 7.5.1 TRXVU interface control document
    instances:
        instantaneous_received_signal_doppler_hz:
          value: (instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        instantaneous_received_signal_strength_d_bm:
          value: instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        supply_voltage_v:
          value: supply_voltage*0.00488
        total_supply_current_m_a:
          value: total_supply_current*0.16643964
        transmitter_current_m_a:
          value: transmitter_current*0.16643964
        receiver_current_m_a:
          value: receiver_current*0.16643964
        power_amplifier_current_m_a:
          value: power_amplifier_current*0.16643964
        power_amplifier_temperature_c:
          value: (power_amplifier_temperature)*-0.07669+195.6037
        local_oscillator_temperature_c:
          value: (local_oscillator_temperature)*-0.07669+195.6037
        trxvu_rx_uptime_raw:
          value: trxvu_rx_uptime        
################################################################################
#
#   OBC HK
#
################################################################################          
  obc_hk:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_enable_status
        type: u4
      - id: supervisor_uptime
        type: u4
      - id: iobc_reset_count
        type: u4
      - id: iobc_measure_temperature
        type: u2
      - id: iobc_measure3v3in
        type: u2
      - id: iobc_measure3v3
        type: u2
      - id: iobc_measure2v_reference
        type: u2
      - id: iobc_measure1v8
        type: u2
      - id: iobc_measure1v0
        type: u2
      - id: iobc_measure_current3v3
        type: u2
      - id: iobc_measure_current1v8
        type: u2
      - id: iobc_measure_current1v0
        type: u2
      - id: iobc_measure_volt_rtc
        type: u2
      - id: iobc_adc_update_flag
        type: u1
      - id: iobc_crc8
        type: u1
      - id: photodiode1
        type: u2
      - id: photodiode2
        type: u2
      - id: photodiode3
        type: u2
      - id: photodiode4
        type: u2
      - id: photodiode5
        type: u2
      - id: photodiode6
        type: u2
      - id: panel_temperature1
        type: u4
      - id: panel_temperature2
        type: u4
      - id: panel_temperature3
        type: u4
      - id: panel_temperature4
        type: u4
      - id: panel_temperature5
        type: u4
      - id: panel_temperature6
        type: u4
    instances:
      spi_command_status_raw:
        value: spi_command_status
      supervisor_enable_status_raw:
        value: supervisor_enable_status
      supervisor_uptime_raw:
        value: supervisor_uptime
      iobc_reset_count_raw:
        value: iobc_reset_count
      iobc_measure_temperature_raw:
        value: iobc_measure_temperature
      iobc_measure3v3in_raw:
        value: iobc_measure3v3in
      iobc_measure3v3_raw:
        value: iobc_measure3v3
      iobc_measure2v_reference_raw:
        value: iobc_measure2v_reference
      iobc_measure1v8_raw:
        value: iobc_measure1v8
      iobc_measure1v0_raw:
        value: iobc_measure1v0
      iobc_measure_current3v3_raw:
        value: iobc_measure_current3v3
      iobc_measure_current1v8_raw:
        value: iobc_measure_current1v8
      iobc_measure_current1v0_raw:
        value: iobc_measure_current1v0
      iobc_measure_volt_rtc_raw:
        value: iobc_measure_volt_rtc
      iobc_adc_update_flag_raw:
        value: iobc_adc_update_flag
      iobc_crc8_raw:
        value: iobc_crc8
      photodiode1_raw:
        value: photodiode1
      photodiode2_raw:
        value: photodiode2
      photodiode3_raw:
        value: photodiode3
      photodiode4_raw:
        value: photodiode4
      photodiode5_raw:
        value: photodiode5
      photodiode6_raw:
        value: photodiode6
      panel_temperature1_c:
        value:  panel_temperature1 / 1024.0
      panel_temperature2_c:
        value:  panel_temperature2 / 1024.0
      panel_temperature3_c:
        value:  panel_temperature3 / 1024.0
      panel_temperature4_c:
        value:  panel_temperature4 / 1024.0
      panel_temperature5_c:
        value:  panel_temperature5 / 1024.0
      panel_temperature6_c:
        value:  panel_temperature6 / 1024.0
        

################################################################################
#
#   ieps HK status
#
################################################################################

  ieps_hk_status:
      seq:
      - id: h_k_stid 
        type: u1
      - id: h_k_ivid 
        type: u1
      - id: h_k_rc 
        type: u1
      - id: h_k_bid 
        type: u1
      - id: h_k_cmderr 
        type: b4
      - id: h_k_stat 
        type: b4
      - id: volt_brd_sup_raw
        type: u2
      - id: temp_raw
        type: u2
      - id: v_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: i_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: p_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: v_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: i_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: p_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: bat_temp2raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_o_b_c00
        type: u2
      - id: i_o_b_c00
        type:  u2
      - id: p_o_b_c00
        type:  u2
      - id: v_o_b_c01
        type: u2
      - id: i_o_b_c01
        type:  u2
      - id: p_o_b_c01
        type:  u2
      - id: v_o_b_c02
        type: u2
      - id: i_o_b_c02
        type:  u2
      - id: p_o_b_c02
        type:  u2
      - id: v_o_b_c03
        type: u2
      - id: i_o_b_c03
        type:  u2
      - id: p_o_b_c03
        type:  u2
      - id: v_o_b_c05
        type: u2
      - id: i_o_b_c05
        type:  u2
      - id: p_o_b_c05
        type:  u2
      - id: v_o_b_c06
        type: u2
      - id: i_o_b_c06
        type:  u2
      - id: p_o_b_c06
        type:  u2
      - id: cc1
        size: 8
      - id: cc2
        size: 8
      - id: cc3
        size: 8
      - id: status_stid 
        type: u1
      - id: status_ivid 
        type: u1
      - id: status_rc 
        type: u1
      - id: status_bid 
        type: u1
      - id: status_cmderr 
        type: b4
      - id: status_stat 
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2
      instances:
        h_k_stid_raw: 
         value: h_k_stid
        h_k_ivid_raw:  
         value: h_k_ivid
        h_k_rc_raw:  
         value: h_k_rc
        h_k_bid_raw:  
         value: h_k_bid
        h_k_cmderr_raw:  
         value: h_k_cmderr
        h_k_stat_raw:  
         value: h_k_stat
        volt_brd_sup_raw_raw: 
         value: volt_brd_sup_raw
        temp_raw_raw: 
         value: temp_raw
        v_d_i_s_t_i_n_p_u_traw_raw: 
         value: v_d_i_s_t_i_n_p_u_traw
        i_d_i_s_t_i_n_p_u_traw_raw: 
         value: i_d_i_s_t_i_n_p_u_traw
        p_d_i_s_t_i_n_p_u_traw_raw: 
         value: p_d_i_s_t_i_n_p_u_traw
        v_b_a_t_t_i_n_p_u_traw_raw: 
         value: v_b_a_t_t_i_n_p_u_traw
        i_b_a_t_t_i_n_p_u_traw_raw: 
         value: i_b_a_t_t_i_n_p_u_traw
        p_b_a_t_t_i_n_p_u_traw_raw:
         value: p_b_a_t_t_i_n_p_u_traw
        stat_obc_on_raw: 
         value: stat_obc_on
        stat_obc_ocf_raw: 
         value: stat_obc_ocf
        bat_stat_raw: 
         value: bat_stat
        bat_temp2raw_raw: 
         value: bat_temp2raw
        v_o_b_c00_v:
         value: v_o_b_c00  
        i_o_b_c00_a:
         value: i_o_b_c00
        p_o_b_c00_a:
         value: p_o_b_c00 
        v_o_b_c01_v:
         value: v_o_b_c01  
        i_o_b_c01_a:
         value: i_o_b_c01 
        p_o_b_c01_a:
         value: p_o_b_c01
        v_o_b_c02_v:
         value: v_o_b_c02  
        i_o_b_c02_a:
         value: i_o_b_c02 
        p_o_b_c02_a:
         value: p_o_b_c02    
        v_o_b_c03_v:
         value: v_o_b_c03  
        i_o_b_c03_a:
         value: i_o_b_c03 
        p_o_b_c03_a:
         value: p_o_b_c03 
        v_o_b_c05_v:
         value: v_o_b_c05  
        i_o_b_c05_a:
         value: i_o_b_c05 
        p_o_b_c05_a:
         value: p_o_b_c05
        v_o_b_c06_v:
         value: v_o_b_c06  
        i_o_b_c06_a:
         value: i_o_b_c06 
        p_o_b_c06_a:
         value: p_o_b_c06
        cc1_raw:
         value: cc1
        cc2_raw:
         value: cc2
        cc3_raw:
         value: cc3
        status_stid_raw: 
         value: status_stid
        status_ivid_raw:
         value: status_ivid
        status_rc_raw:
         value: status_rc
        status_bid_raw: 
         value: status_bid
        status_cmderr_raw: 
         value: status_cmderr
        status_stat_raw: 
         value: status_stat
        mode_raw:
         value: mode
        conf_raw:
         value: conf
        reset_cause_raw:
         value: reset_cause
        uptime_raw:
         value: uptime
        error_raw:
         value: error
        rc_cnt_pwron_raw:
         value: rc_cnt_pwron
        rc_cnt_wdg_raw:
         value: rc_cnt_wdg
        rc_cnt_cmd_raw:
         value: rc_cnt_cmd
        rc_cnt_mcu_raw:
         value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
         value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
         value: prevcmd_elapsed
################################################################################
#
#   OBC Status
#
################################################################################
  obc_status:
    seq:
      - id: dummy
        type: u1
      - id: spi_command_status
        type: u1
      - id: supervisor_index_of_subsystem
        type: u1
      - id: supervisor_major_version
        type: u1
      - id: supervisor_minor_version
        type: u1
      - id: supervisor_patch_version
        type: u1
      - id: supervisor_git_head_version
        type: u4
      - id: supervisor_serial_number
        type: u2
      - id: compilation_information
        size: 19
      - id: clock_speed
        type: u1
      - id: code_type
        type: u1
      - id: crc_8
        type: u1
      - id: sw_mmode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reserved 
        type: u1
      - id: nb_reset
        type: u1
      - id: reserved2 
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: sdcard_status
        type: u1
      - id: sdcard_last_error
        type: u4
      - id: old_time_t_m_in_sdcard
        type: b56
      - id: new_time_t_m_in_sdcard
        type: b56
    instances:
      dummydummy:
       value: dummy
      spi_command_status_raw:
       value: spi_command_status
      supervisor_index_of_subsystem_raw:
       value: supervisor_index_of_subsystem
      supervisor_major_version_raw:
       value: supervisor_major_version
      supervisor_minor_version_raw:
       value: supervisor_minor_version
      supervisor_patch_version_raw:
       value: supervisor_patch_version
      supervisor_git_head_version_raw:
       value: supervisor_git_head_version
      supervisor_serial_number_raw:
       value: supervisor_serial_number
      compilation_information_raw:
       value: compilation_information
      clock_speed_raw:
       value: clock_speed
      code_type_raw:
       value: code_type
      crc_8_raw:
       value: crc_8
      sw_mmode_raw:
       value: sw_mmode
      last_reset_reason_raw:
       value: last_reset_reason
      reserved_raw:
       value: reserved
      nb_reset_raw:
       value: nb_reset
      reserved2_raw: 
       value: reserved2
      deploy_antennas_system_raw:
       value: deploy_antennas_system
      nb_tm_since_first_start_raw:
       value: nb_tm_since_first_start
      nb_tc_since_first_start_raw:
       value: nb_tc_since_first_start
      nb_bad_tc_since_first_start_raw:
       value: nb_bad_tc_since_first_start
      nb_tm_in_sdcard_raw:
       value: nb_tm_in_sdcard
      sdcard_status_raw:
       value: sdcard_status
      sdcard_last_error_raw:
       value: sdcard_last_error
      old_time_t_m_in_sdcard_raw:
       value: old_time_t_m_in_sdcard
      new_time_t_m_in_sdcard_raw:
       value: new_time_t_m_in_sdcard    
################################################################################
#
#   trxvutx HK
#
################################################################################    
    
  trxvutx_hk:
    seq:
      - id: instantaneous_rf_reflected_power_from_transmitter_port
        type : b12
      - id: instantaneous_rf_forward_power_from_transmitter_port
        type : b12
      - id: supply_voltage
        type : b12
      - id: total_supply_current
        type : b12
      - id: transmitter_current
        type : b12
      - id: receiver_current
        type : b12
      - id: power_amplifier_current
        type : b12
      - id: power_amplifier_temperature
        type : b12 
      - id: local_oscillator_temperature
        type : b12
      - id: zero_padding
        type: b4 
      - id: trxvu_tx_uptime
        type: u4
      - id: trxvu_tx_state
        type: u1 
    instances:
        instantaneous_rf_reflected_power_from_transmitter_port_mw:
          value: instantaneous_rf_reflected_power_from_transmitter_port * instantaneous_rf_reflected_power_from_transmitter_port * 5.887 * 0.00001
        instantaneous_rf_forward_power_from_transmitter_port_mw:
          value: instantaneous_rf_forward_power_from_transmitter_port * instantaneous_rf_forward_power_from_transmitter_port * 5.887 * 0.00001
        supply_voltage_v:
          value: 0.00488 * supply_voltage   
        total_supply_current_ma: 
          value: 0.16643964 * total_supply_current 
        transmitter_current_ma:
          value: transmitter_current * 0.16643964
        receiver_current_ma:
          value: receiver_current * 0.16643964
        power_amplifier_current_ma:
          value: power_amplifier_current * 0.16643964
        power_amplifier_temperature_t:
          value: power_amplifier_temperature * -0.07669 + 195.6037
        local_oscillator_temperature_t:
          value: local_oscillator_temperature * -0.07669 + 195.6037
        zero_padding_raw:
          value: zero_padding
        trxvu_tx_uptime_raw:
          value: trxvu_tx_uptime
        trxvu_tx_state_raw:
          value:  trxvu_tx_state
        
################################################################################
#
#   imtq  HK
#
################################################################################        
        
  imtq_hk:
    seq:
      - id: digitale_voltage
        type: u2  
      - id: analog_voltage
        type: u2   
      - id: digital_current
        type: u2  
      - id: analog_current
        type: u2  
      - id: measure_coil_x_current
        type: u2  
      - id: measure_coil_y_current
        type: u2  
      - id: measure_coil_z_current
        type: u2  
      - id: measure_coil_x_temperature
        type: u2  
      - id: measure_coil_y_temperature
        type: u2  
      - id: measure_coil_z_temperature
        type: u2  
      - id: mcu_temperature
        type: u2  
      - id: i_m_t_q_system_state_mode
        type: u1 
      - id: i_m_t_q_system_state_error
        type: u1  
      - id: i_m_t_q_system_state_configuration
        type: u1
      - id: i_m_t_q_system_state_uptime
        type: u4
    instances:
        digitale_voltage_v:
          value: 2 *  (2.5/4095) * digitale_voltage   
        analog_voltage_v: 
          value: 2 *  (2.5/4095) * analog_voltage
        digital_current_raw:
          value: digital_current  
        analog_current_raw:
          value: analog_current 
        measure_coil_x_current_a:
          value:   (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_a:
          value:   (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_a:
          value:   (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_t:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_t:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_t:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        mcu_temperature_t:
          value:  (( (2.5/4095) * mcu_temperature) -0.680) * - 1.0 /0.00225
        i_m_t_q_system_state_mode_raw:
          value: i_m_t_q_system_state_mode 
        i_m_t_q_system_state_error_raw:
          value: i_m_t_q_system_state_error  
        i_m_t_q_system_state_configuration_raw:
          value: i_m_t_q_system_state_configuration
        i_m_t_q_system_state_uptime_raw:
          value: i_m_t_q_system_state_uptime          
          
################################################################################
#
#   beacon
#
################################################################################           
          
  beacon:
    seq:
      - id: sw_mode
        type: u1
      - id: last_reset_reason
        type: u1
      - id: reset_order
        type: u1
      - id: nb_reset
        type: u1
      - id: format_sdcard_order
        type: u1
      - id: deploy_antennas_system
        type: u1
      - id: nb_tm_since_first_start
        type: u4
      - id: nb_tc_since_first_start
        type: u4
      - id: nb_tc_ping_since_first_start
        type: u4
      - id: nb_bad_tc_since_first_start
        type: u4
      - id: nb_tm_in_sdcard
        type: u4
      - id: instantaneous_r_f_reflected_power_from_transmitter_port
        type: b12
      - id: instantaneous_r_f_forward_power_from_transmitter_port
        type: b12
      - id: supply_voltage
        type: b12
      - id: total_supply_current
        type: b12
      - id: transmitter_current
        type: b12
      - id: receiver_current
        type: b12
      - id: power_amplifier_current
        type: b12
      - id: power_amplifier_temperature
        type: b12
      - id: local_oscillator_temperature
        type: b12
      - id: instantaneous_received_signal_doppler_offset_at_the_receiver_port
        type: b12
      - id: instantaneous_received_signal_strength_at_the_receiver_port
        type: b12
      - id: trxvu_supply_voltage
        type: b12
      - id: trxvu_total_supply_current
        type: b12
      - id: trxvu_transmitter_current
        type: b12
      - id: trxvu_receiver_current
        type: b12
      - id: trxvu_power_amplifier_current
        type: b12
      - id: trxvu_power_amplifier_temperature
        type: b12
      - id: trxvu_local_oscillator_temperature
        type: b12
      - id: i_m_t_q_system_state_mode
        type: u1
      - id: measure_coil_x_current
        type: u2
      - id: measure_coil_y_current
        type: u2
      - id: measure_coil_z_current
        type: u2
      - id: measure_coil_x_temperature
        type: u2
      - id: measure_coil_y_temperature
        type: u2
      - id: measure_coil_z_temperature
        type: u2
      - id: m_c_u_temperature
        type: u2
      - id: s_i_d_e_a_ants_temperature
        type: u2
      - id: s_i_d_e_a_ants_deployment_status
        type: u2
      - id: v_o_l_t__b_r_d_s_u_praw
        type: u2
      - id: t_e_m_p_raw
        type: u2
      - id: v_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: i_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: p_d_i_s_t_i_n_p_u_traw
        type: u2
      - id: v_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: i_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: p_b_a_t_t_i_n_p_u_traw
        type: u2
      - id: stat_obc_on
        type: u2
      - id: stat_obc_ocf
        type: u2
      - id: bat_stat
        type: u2
      - id: b_a_t__t_e_m_p2_raw
        type: u2
      - id: volt_vd0
        type: u2
      - id: volt_vd1
        type: u2
      - id: volt_vd2
        type: u2
      - id: v_o_b_c00
        type: u2
      - id: i_o_b_c00
        type:  u2
      - id: p_o_b_c00
        type:  u2
      - id: v_o_b_c01
        type: u2
      - id: i_o_b_c01
        type:  u2
      - id: p_o_b_c01
        type:  u2
      - id: v_o_b_c02
        type: u2
      - id: i_o_b_c02
        type:  u2
      - id: p_o_b_c02
        type:  u2
      - id: v_o_b_c03
        type: u2
      - id: i_o_b_c03
        type:  u2
      - id: p_o_b_c03
        type:  u2
      - id: v_o_b_c05
        type: u2
      - id: i_o_b_c05
        type:  u2
      - id: p_o_b_c05
        type:  u2
      - id: v_o_b_c06
        type: u2
      - id: i_o_b_c06
        type:  u2
      - id: p_o_b_c06
        type:  u2
      - id: status_stid
        type: u1
      - id: status_ivid
        type: u1
      - id: status_rc
        type: u1
      - id: status_bid
        type: u1
      - id: status_cmderr
        type: b4
      - id: status_stat
        type: b4
      - id: mode
        type: u1
      - id: conf
        type: u1
      - id: reset_cause
        type: u1
      - id: uptime
        type: u4
      - id: error
        type: u2
      - id: rc_cnt_pwron
        type: u2
      - id: rc_cnt_wdg
        type: u2
      - id: rc_cnt_cmd
        type: u2
      - id: rc_cnt_mcu
        type: u2     
      - id: rc_cnt_emlopo
        type: u2
      - id: prevcmd_elapsed
        type: u2      
      - id: photodiode1
        type: u2
      - id: photodiode2
        type: u2
      - id: photodiode3
        type: u2
      - id: photodiode4
        type: u2
      - id: photodiode5
        type: u2
      - id: photodiode6
        type: u2
      - id: panel_temperature1
        type: u4
      - id: panel_temperature2
        type: u4
      - id: panel_temperature3
        type: u4
      - id: panel_temperature4
        type: u4
      - id: panel_temperature5
        type: u4
      - id: panel_temperature6
        type: u4    

    instances: 

        sw_mode_raw:
          value:  sw_mode
        last_reset_reason_raw:
          value:  last_reset_reason
        reset_order_raw:
          value:  reset_order
        nb_reset_raw:
          value:  nb_reset
        format_sdcard_order_raw:
          value:  format_sdcard_order
        deploy_antennas_system_raw:
          value:  deploy_antennas_system
        nb_tm_since_first_start_raw:
          value:  nb_tm_since_first_start
        nb_tc_since_first_start_raw:
          value:  nb_tc_since_first_start
        nb_tc_ping_since_first_start_raw:
          value:  nb_tc_ping_since_first_start
        nb_bad_tc_since_first_start_raw:
          value:  nb_bad_tc_since_first_start
        nb_tm_in_sdcard_raw:
          value:  nb_tm_in_sdcard
        instantaneous_r_f_reflected_power_from_transmitter_port_raw:
          value: instantaneous_r_f_reflected_power_from_transmitter_port
        instantaneous_r_f_forward_power_from_transmitter_port_raw:
          value: instantaneous_r_f_forward_power_from_transmitter_port
        supply_voltage_v:
          value: 0.00488 * supply_voltage 
        total_supply_current_ma: 
          value: 0.16643964 * total_supply_current 
        transmitter_current_ma:
          value: transmitter_current * 0.16643964
        receiver_current_ma:
          value: receiver_current * 0.16643964
        power_amplifier_current_ma:
          value: power_amplifier_current * 0.16643964
        power_amplifier_temperature_t:
          value: power_amplifier_temperature * -0.07669 + 195.6037
        local_oscillator_temperature_t:
          value: local_oscillator_temperature * -0.07669 + 195.6037
        instantaneous_received_signal_doppler_hz:
          value: (instantaneous_received_signal_doppler_offset_at_the_receiver_port * 13.552) - 22300        
        instantaneous_received_signal_strength_d_bm:
          value: instantaneous_received_signal_strength_at_the_receiver_port*0.03-152
        trxvu_supply_voltage_raw:
          value: trxvu_supply_voltage
        trxvu_total_supply_current_raw:
          value: trxvu_total_supply_current
        trxvu_transmitter_current_raw:
          value: trxvu_transmitter_current
        trxvu_receiver_current_raw:
          value: trxvu_receiver_current
        trxvu_power_amplifier_current_raw:
          value: trxvu_power_amplifier_current
        trxvu_power_amplifier_temperature_raw:
          value: trxvu_power_amplifier_temperature
        trxvu_local_oscillator_temperature_raw:
          value: trxvu_local_oscillator_temperature
        i_m_t_q_system_state_mode_raw:
          value: i_m_t_q_system_state_mode
        measure_coil_x_current_a:
          value:   (( (2.5/4095) * measure_coil_x_current) -1.03)/2.0
        measure_coil_y_current_a:
          value:   (( (2.5/4095) * measure_coil_y_current) -1.03)/2.0
        measure_coil_z_current_a:
          value:   (( (2.5/4095) * measure_coil_z_current) -1.03)/0.48   
        measure_coil_x_temperature_t:
          value: (( (2.5/4095) * measure_coil_x_temperature) -1.567) * -1.0 /0.0081
        measure_coil_y_temperature_t:
          value: (( (2.5/4095) * measure_coil_y_temperature) -1.567) * -1.0 /0.0081 
        measure_coil_z_temperature_t:
          value: (( (2.5/4095) * measure_coil_z_temperature) -1.567) * -1.0 /0.0081        
        m_c_u_temperature_raw:
          value: m_c_u_temperature
        s_i_d_e_a_ants_temperature_raw:
          value: s_i_d_e_a_ants_temperature
        s_i_d_e_a_ants_deployment_status_raw:
          value: s_i_d_e_a_ants_deployment_status
        v_o_l_t__b_r_d_s_u_praw_raw:
          value: v_o_l_t__b_r_d_s_u_praw
        t_e_m_p_raw_raw:
          value: t_e_m_p_raw
        v_d_i_s_t_i_n_p_u_traw_raw:
          value: v_d_i_s_t_i_n_p_u_traw
        i_d_i_s_t_i_n_p_u_traw_raw:
          value: i_d_i_s_t_i_n_p_u_traw
        p_d_i_s_t_i_n_p_u_traw_raw:
          value: p_d_i_s_t_i_n_p_u_traw
        v_b_a_t_t_i_n_p_u_traw_raw:
          value: v_b_a_t_t_i_n_p_u_traw
        i_b_a_t_t_i_n_p_u_traw_raw:
          value: i_b_a_t_t_i_n_p_u_traw
        p_b_a_t_t_i_n_p_u_traw_raw:
          value: p_b_a_t_t_i_n_p_u_traw
        stat_obc_on_raw:
          value: stat_obc_on
        stat_obc_ocf_raw:
          value: stat_obc_ocf
        bat_stat_raw:
          value: bat_stat
        b_a_t_t_e_m_p2_raw_raw:
          value: b_a_t__t_e_m_p2_raw
        v_o_b_c00_v:
         value: v_o_b_c00  
        i_o_b_c00_a:
         value: i_o_b_c00
        p_o_b_c00_mw:
         value: p_o_b_c00 
        v_o_b_c01_v:
         value: v_o_b_c01  
        i_o_b_c01_a:
         value: i_o_b_c01 
        p_o_b_c01_mw:
         value: p_o_b_c01
        v_o_b_c02_v:
         value: v_o_b_c02  
        i_o_b_c02_a:
         value: i_o_b_c02 
        p_o_b_c02_mw:
         value: p_o_b_c02    
        v_o_b_c03_v:
         value: v_o_b_c03  
        i_o_b_c03_a:
         value: i_o_b_c03 
        p_o_b_c03_mw:
         value: p_o_b_c03 
        v_o_b_c05_v:
         value: v_o_b_c05  
        i_o_b_c05_a:
         value: i_o_b_c05 
        p_o_b_c05_mw:
         value: p_o_b_c05
        v_o_b_c06_v:
         value: v_o_b_c06  
        i_o_b_c06_a:
         value: i_o_b_c06 
        p_o_b_c06_mw:
         value: p_o_b_c06
        status_stid_raw:
          value: status_stid
        status_ivid_raw:
          value: status_ivid
        status_rc_raw:
          value: status_rc
        status_bid_raw:
          value: status_bid
        status_cmderr_raw:
          value: status_cmderr
        status_stat_raw:
          value: status_stat
        mode_raw:
          value: mode
        conf_raw:
          value: conf
        reset_cause_raw:
          value: reset_cause
        uptime_raw:
          value: uptime
        error_raw:
          value: error
        rc_cnt_pwron_raw:
          value: rc_cnt_pwron
        rc_cnt_wdg_raw:
          value: rc_cnt_wdg
        rc_cnt_cmd_raw:
          value: rc_cnt_cmd
        rc_cnt_mcu_raw:
          value: rc_cnt_mcu
        rc_cnt_emlopo_raw:
          value: rc_cnt_emlopo
        prevcmd_elapsed_raw:
          value: prevcmd_elapsed
        photodiode1_raw:
          value: photodiode1
        photodiode2_raw:
          value: photodiode2
        photodiode3_raw:
          value: photodiode3
        photodiode4_raw:
          value: photodiode4
        photodiode5_raw:
          value: photodiode5
        photodiode6_raw:
          value: photodiode6
        panel_temperature1_c:
          value:  panel_temperature1 / 1024.0
        panel_temperature2_c:
          value:  panel_temperature2 / 1024.0
        panel_temperature3_c:
          value:  panel_temperature3 / 1024.0
        panel_temperature4_c:
          value:  panel_temperature4 / 1024.0
        panel_temperature5_c:
          value:  panel_temperature5 / 1024.0
        panel_temperature6_c:
          value:  panel_temperature6 / 1024.0



  
       
